summaryrefslogtreecommitdiff
path: root/src/mongo/db
diff options
context:
space:
mode:
authorEliot Horowitz <eliot@10gen.com>2014-05-06 12:05:12 -0400
committerEliot Horowitz <eliot@10gen.com>2014-05-06 12:06:58 -0400
commit298a2652a956c823b265cb742b56ce7dec86ef66 (patch)
tree19a7c5292881e3242ba5ca8a13aca6f207e7fd31 /src/mongo/db
parent8ad5c39a929ee887ba12bcf7f38f319b9908747a (diff)
downloadmongo-298a2652a956c823b265cb742b56ce7dec86ef66.tar.gz
SERVER-13640: better variable names
Diffstat (limited to 'src/mongo/db')
-rw-r--r--src/mongo/db/storage/extent_manager.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/mongo/db/storage/extent_manager.h b/src/mongo/db/storage/extent_manager.h
index 5604cae70a0..f4bb4c1a8c5 100644
--- a/src/mongo/db/storage/extent_manager.h
+++ b/src/mongo/db/storage/extent_manager.h
@@ -132,15 +132,15 @@ namespace mongo {
virtual int minSize() const { return 0x1000; }
/**
* @param len lengt of record we need
* @param lastRecord size of last extent which is a factor in next extent size
*/
- virtual int followupSize( int len, int lastExtentLen ) const;
+ virtual int followupSize( int recordLen, int lastExtentLen ) const;
/** get a suggested size for the first extent in a namespace
* @param len length of record we need to insert
*/
- virtual int initialSize( int len ) const;
+ virtual int initialSize( int recordLen ) const;
/**
* quantizes extent size to >= min + page boundary
@@ -132,15 +132,15 @@ namespace mongo {
virtual int minSize() const { return 0x1000; }
/**
- * @param len lengt of record we need
- * @param lastRecord size of last extent which is a factor in next extent size
+ * @param recordLen length of record we need
+ * @param lastExt size of last extent which is a factor in next extent size
*/
@@ -132,15 +132,15 @@ namespace mongo {
/** get a suggested size for the first extent in a namespace
- * @param len length of record we need to insert
+ * @param recordLen length of record we need to insert
*/